"""Version number of Bumplus."""
from __future__ import absolute_import, division, print_function

__version__ = "0.10.0"
